==> CallApiCPlusPlus-0.2.1.zip: CallApiCPlusPlus-0.2.1/src/main.cpp <==
/*******************************************************************************
**
** Copyright (C) 2022 ru.auroraos
**
** This file is part of the Моё приложение для ОС Аврора project.
**
** Redistribution and use in source and binary forms,
** with or without modification, are permitted provided
** that the following conditions are met:
**
** * Redistributions of source code must retain the above copyright notice,
**   this list of conditions and the following disclaimer.
** * Redistributions in binary form must reproduce the above copyright notice,
**   this list of conditions and the following disclaimer
**   in the documentation and/or other materials provided with the distribution.
** * Neither the name of the copyright holder nor the names of its contributors
**   may be used to endorse or promote products derived from this software
**   without specific prior written permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
** AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
** THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
** FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
** IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
** FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
** OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
** PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
** LOSS OF USE, DATA, OR PROFITS;
** OR BUSINESS INTERRUPTION)
** HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE)
** ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
** EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
*******************************************************************************/

#include <auroraapp.h>
#include <QtQuick>
#include <QQmlEngine>
#include <QQmlContext>

#include "audiocall.h"
#include "audiocallmanager.h"
#include "urihandler.h"

int main(int argc, char *argv[])
{
    QScopedPointer<QGuiApplication> application(Aurora::Application::application(argc, argv));
    application->setOrganizationName(QStringLiteral("ru.auroraos"));
    application->setApplicationName(QStringLiteral("AudioCallExample"));

    qRegisterMetaType<ru::auroraos::call::Call*>("Call*");
    qmlRegisterUncreatableType<ru::auroraos::call::Call>("AudioCallExample", 1, 0, "Call", QStringLiteral("Call"));

    qRegisterMetaType<AudioCall*>("AudioCall*");
    qmlRegisterUncreatableType<AudioCall>("AudioCallExample", 1, 0, "AudioCall", QStringLiteral("AudioCall"));

    qRegisterMetaType<ru::auroraos::call::AudioDevice>("AudioDevice");
    qRegisterMetaType<ru::auroraos::call::AudioDevice::Type>("AudioDeviceType");
    qRegisterMetaType<ru::auroraos::call::AudioDeviceList>("AudioDeviceList");
    qmlRegisterUncreatableType<ru::auroraos::call::AudioDevice>("AudioCallExample", 1, 0, "AudioDevice", QStringLiteral("AudioDevice"));

    AudioCallManager callManager(QStringLiteral("account0"));
    UriHandler uriHandler;
    QObject::connect(&uriHandler, &UriHandler::openedUri,
                     &callManager, &AudioCallManager::openUri);

    QScopedPointer<QQuickView> view(Aurora::Application::createView());
    auto rootContext = view->engine()->rootContext();
    rootContext->setContextProperty("callManager", &callManager);
    view->setSource(Aurora::Application::pathTo(QStringLiteral("qml/AudioCallExample.qml")));
    view->show();

    return application->exec();
}

==> CallApiCPlusPlus-0.2.3.zip: CallApiCPlusPlus-0.2.3/src/main.cpp <==
/*******************************************************************************
**
** Copyright (C) 2022 ru.auroraos
**
** This file is part of the Моё приложение для ОС Аврора project.
**
** Redistribution and use in source and binary forms,
** with or without modification, are permitted provided
** that the following conditions are met:
**
** * Redistributions of source code must retain the above copyright notice,
**   this list of conditions and the following disclaimer.
** * Redistributions in binary form must reproduce the above copyright notice,
**   this list of conditions and the following disclaimer
**   in the documentation and/or other materials provided with the distribution.
** * Neither the name of the copyright holder nor the names of its contributors
**   may be used to endorse or promote products derived from this software
**   without specific prior written permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
** AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
** THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
** FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
** IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
** FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
** OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
** PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
** LOSS OF USE, DATA, OR PROFITS;
** OR BUSINESS INTERRUPTION)
** HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE)
** ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
** EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
*******************************************************************************/

#include <auroraapp.h>
#include <QtQuick>
#include <QQmlEngine>
#include <QQmlContext>

#include "audiocall.h"
#include "audiocallmanager.h"
#include "audiomanager.h"
#include "urihandler.h"

namespace {

void registerQmlTypes()
{
    qRegisterMetaType<ru::auroraos::call::Call*>("Call*");
    qmlRegisterUncreatableType<ru::auroraos::call::Call>("AudioCallExample", 1, 0, "Call", QStringLiteral("Call"));

    qRegisterMetaType<AudioCall*>("AudioCall*");
    qmlRegisterUncreatableType<AudioCall>("AudioCallExample", 1, 0, "AudioCall", QStringLiteral("AudioCall"));

    qmlRegisterUncreatableType<ru::auroraos::call::AudioDevice>("AudioCallExample", 1, 0, "AudioDevice", QStringLiteral("AudioDevice"));
}

}

Q_CONSTRUCTOR_FUNCTION(registerQmlTypes)

int main(int argc, char *argv[])
{
    QScopedPointer<QGuiApplication> application(Aurora::Application::application(argc, argv));
    application->setOrganizationName(QStringLiteral("ru.auroraos"));
    application->setApplicationName(QStringLiteral("AudioCallExample"));

    AudioCallManager callManager(QStringLiteral("account0"));
    UriHandler uriHandler;
    QObject::connect(&uriHandler, &UriHandler::openedUri,
                     &callManager, &AudioCallManager::openUri);

    QScopedPointer<QQuickView> view(Aurora::Application::createView());
    auto rootContext = view->engine()->rootContext();
    rootContext->setContextProperty("callManager", &callManager);
    view->setSource(Aurora::Application::pathTo(QStringLiteral("qml/AudioCallExample.qml")));
    view->show();

    return application->exec();
}
